fluteline - easy thread based pipeline
======================================

.. image:: https://readthedocs.org/projects/fluteline/badge/?version=latest
    :target: https://fluteline.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/Nagasaki45/fluteline.svg?branch=master
    :target: https://travis-ci.org/Nagasaki45/fluteline

Easy to use pipelines of producers, consumers, and consumer-producers, in pure python (2 and 3) and with no dependencies.

Why fluteline?
--------------

Pypi is full of projects with "pipe" in their name, and flutes are, uh... similar?
